<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\Traits\HasPlaceholderProperty;

readonly class PasswordFormKitField extends FormKitField
{
    protected final const string TYPE = 'password';

    use HasPlaceholderProperty;
}
