<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\Traits\HasPlaceholderProperty;

readonly class TextareaFormKitField extends FormKitField
{
    use HasPlaceholderProperty;

    protected final const string TYPE = 'textarea';

}
