<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\Traits\HasOptionsProperty;

readonly class CheckboxGroupFormKitField extends FormKitField
{
    use HasOptionsProperty;

    final protected const string TYPE = 'checkbox';
}
