<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\FormKitValidation\FormKitValidation;
use apexl\Io\modules\formbuilder\Traits\HasPlaceholderProperty;

readonly class EmailFormKitField extends FormKitField
{
    protected final const string TYPE = 'email';

    use HasPlaceholderProperty;

    public function init(): void
    {
        $this->addValidation(FormKitValidation::email());
    }
}
